/* $Id: accel.h,v 1.3 1998/11/24 18:45:21 marcus Exp $
******************************************************************************

   S3 accelerator -- register definitions

   Copyright (C) 1996		Steffen Seeger	[seeger@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/


#ifndef _S3_accel_h
#define _S3_accel_h

/* enhanced command registers */
#define	AC_SUBSYS_STAT	0x42E8	/* read only	*/
#define	ECR_SUBSYS_STAT	0x42E8	/* obsolete!	*/
	#define	EC00_VSYNC_IRQ	0x0001
	#define	EC00_GEBUSY_IRQ	0x0002
	#define	EC00_FIFO_F_IRQ	0x0004
	#define	EC00_FIFO_E_IRQ	0x0008
	#define	EC00_IRQ_MASK	0x000F
	#define	EC00_GIP_MASK	0x0070
	#define	EC00_8BPP	0x0080

#define	AC_SUBSYS_CNTL	0x42E8	/* write only	*/
#define	ECR_SUBSYS_CNTL	0x42E8	/* obsolete!	*/
	#define	EC00_VSYNC_CLR	0x0001
	#define	EC00_GEBUSY_CLR	0x0002
	#define	EC00_FIFO_F_CLR	0x0004
	#define	EC00_FIFO_E_CLR	0x0008
	#define	EC00_IRQCLRMASK	0x000F
	#define	EC00_VSYNC_ENB	0x0100
	#define	EC00_GEBUSY_ENB	0x0200
	#define	EC00_FIFO_F_ENB	0x0400
	#define	EC00_FIFO_E_ENB	0x0800
	#define	EC00_RESET	0x8000
	#define	EC00_ENABLE	0x4000

#define	AC_ADVFUNC_CNTL 0x4AE8
#define	ECR_ADVFUNC_CNTL	0x4AE8	/* obsolete!	*/
	#define	EC01_ENH_ENB	0x0001
	#define	EC01_4BPP	0x0004
	#define	EC01_LAW_ENB	0x0010
	#define	EC01_MMIO_ENB	0x0020


/*
**	accelerator registers
*/

#define	ECR_CUR_Y	0x82E8
#define	ECR_CUR_X	0x86E8
#define	ECR_DEST_Y	0x8AE8
#define	ECR_DEST_X	0x8EE8
#define	ECR_AXIAL_STEP	0x8AE8
#define	ECR_DIAG_STEP	0x8EE8
#define	ECR_ERROR_TERM	0x92E8
#define	ECR_MAJAXIS_CNT	0x96E8

#define	ECR_GP_STATUS	0x9AE8	/* read only	*/
	#define	EC06_FIFO_MASK	0xF8ff
	#define	EC06_GE_BUSY	0x0200
	#define	EC06_FIFO_EMPTY	0x0400

#define	ECR_COMMAND	0x9AE8	/* write only	*/
	#define	EC07_NOP	0x0000
	#define	EC07_LINE	0x2000
	#define	EC07_FILLRECT	0x4000
	#define	EC07_BITBLT	0xC000
	#define	EC07_PATFILL	0xE000
	#define	EC07_LITTLE_ENDIAN 0x1000 /* intel byte order */
	#define	EC07_BIG_ENDIAN	0x0000    /* motorola byte order */
	#define	EC07_8BIT_IO	0x0000
	#define	EC07_16BIT_IO	0x0200
	#define	EC07_32BIT_IO	0x0400
	#define	EC07_WAIT_CPU	0x0100
	#define	EC07_DIR(X)	(((X) & 7) << 5)
	#define	EC07_DRAWPIXEL	0x0010
	#define	EC07_DIR_XY	0x0000
	#define	EC07_DIR_RADIAL	0x0008
	#define	EC07_NOT_LAST	0x0004
	#define	EC07_ACROSS_PLANE 0x0002

#define	ECR_SHORT_STROKE 0x9EE8	/* write only	*/
	#define	EC08_STROKE(D,L) (((D) & 7) << 5) | ((L) & 0xF)) 
	#define	EC08_MOVE	0x10

#define	ECR_BACKGROUND	0xA2E8
#define	ECR_FOREGROUND	0xA6E8
#define	ECR_WRITE_MASK	0xAAE8
#define	ECR_READ_MASK	0xAEE8
#define	ECR_CMP_COLOR	0xB2E8

#define	ECR_BACKGR_MIX	0xB6E8
#define	ECR_FOREGR_MIX	0xBAE8
	#define	SRC_BACKGROUND	0x0000
	#define	SRC_FOREGROUND	0x0020
	#define	SRC_CPU		0x0040
	#define	SRC_DISPLAYMEM	0x0060

	#define	MIX_MASK		0x000F
	#define	MIX_NOT_DST		0x0000
	#define	MIX_0			0x0001
	#define	MIX_1			0x0002
	#define	MIX_DST			0x0003
	#define	MIX_NOT_SRC		0x0004
	#define	MIX_XOR			0x0005
	#define	MIX_XNOR		0x0006
	#define	MIX_SRC			0x0007
	#define	MIX_NAND		0x0008
	#define	MIX_NOT_SRC_OR_DST	0x0009
	#define	MIX_SRC_OR_NOT_DST	0x000A
	#define	MIX_OR			0x000B
	#define	MIX_AND			0x000C
	#define	MIX_SRC_AND_NOT_DST	0x000D
	#define	MIX_NOT_SRC_AND_DST	0x000E
	#define	MIX_NOR			0x000F

#define	ECR_MULTIFUNC	0xBEE8
	#define	MF_MINAXIS_CNT	0x0000
	#define	MF_T_CLIP	0x1000
	#define	MF_L_CLIP	0x2000
	#define	MF_B_CLIP	0x3000
	#define	MF_R_CLIP	0x4000
	#define	MF_PIX_CONTROL	0xA000
		#define	MFA_SRC_FOREGR_MIX	0x0000
		#define	MFA_SRC_CPU_SELECT	0x0080
		#define	MFA_SRC_DISPLAYMEM	0x00C0
	#define	MF_MULT_MISC2	0xD000
		#define	SCR_BASE(X)	(((X) & 7) << 6)
		#define	DEST_BASE(X)	((X) & 7)
	#define	MF_MULT_MISC	0xE000
		#define	MFE_DEST_BASE_B20	0x0001
		#define	MFE_DEST_BASE_B21	0x0002
		#define	MFE_SRC_BASE_B20	0x0004
		#define	MFE_SRC_BASE_B21	0x0008
		#define	MFE_HIGH_WORD_IO	0x0010
		#define	MFE_CLIP_OUTSIDE	0x0020
		#define	MFE_SLOW_RMW_CYCLE	0x0040
		#define	MFE_SRC_NE		0x0080
		#define	MFE_ENB_COLOR_CMP	0x0100
		#define	MFE_32BIT_CMD_REGS	0x0200
	#define	MF_READ_SELECT	0xF000

#define	ECR_PIXEL_TRANS	0xE2E8

#endif	/* _S3_accel_h */
